@@ -8,10 +8,10 @@ import coreModule from 'app/core/core_module';
 import { store } from 'app/store/store';
 import { ContextSrv } from 'app/core/services/context_srv';
 import { provideTheme } from 'app/core/utils/ConfigProvider';
-import { ErrorBoundaryAlert } from '@grafana/ui';
+import { ErrorBoundaryAlert, ModalRoot, ModalsProvider } from '@grafana/ui';
 import { GrafanaRootScope } from './GrafanaCtrl';
 
-function WrapInProvider(store: any, Component: any, props: any) {
+export function WrapInProvider(store: any, Component: any, props: any) {
   return (
     <Provider store={store}>
       <ErrorBoundaryAlert style="page">
@@ -21,6 +21,17 @@ function WrapInProvider(store: any, Component: any, props: any) {
   );
 }
 
+export const provideModalsContext = (component: any) => {
+  return (props: any) => (
+    <ModalsProvider>
+      <>
+        {React.createElement(component, { ...props })}
+        <ModalRoot />
+      </>
+    </ModalsProvider>
+  );
+};
+
 /** @ngInject */
 export function reactContainer(
   $route: any,
@@ -52,12 +63,12 @@ export function reactContainer(
         $rootScope: $rootScope,
         $scope: scope,
         $contextSrv: contextSrv,
-        routeInfo: $route.current.$$route.routeInfo,
+        routeInfo: $route.current.$$route?.routeInfo,
       };
 
       document.body.classList.add('is-react');
 
-      ReactDOM.render(WrapInProvider(store, provideTheme(component), props), elem[0]);
+      ReactDOM.render(WrapInProvider(store, provideTheme(provideModalsContext(component)), props), elem[0]);
 
       scope.$on('$destroy', () => {
         document.body.classList.remove('is-react');
